(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    211820,       4599]
NotebookOptionsPosition[    208761,       4497]
NotebookOutlinePosition[    209352,       4518]
CellTagsIndexPosition[    209309,       4515]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["TwoAxisDateListPlot", "Title",
 CellChangeTimes->{3.4619266931944723`*^9}],

Cell["Version 0.51", "Text",
 CellChangeTimes->{3.4778259971232567`*^9, 3.479499982293583*^9}],

Cell["\<\
0.51 Further work to make major and minor left and right ticks align better.\
\>", "Text",
 CellChangeTimes->{{3.477826014525745*^9, 3.477826027203691*^9}, {
  3.479499955836503*^9, 3.479499975225774*^9}}],

Cell["\<\
0.5 Added BarChart support. With option BarChart\[Rule]True the second data \
set is plotted as a bar chart. A combination of line and bar charts seems to \
be how a lot of economic data is plotted. At this stage I have only coded for \
monthly bar charts but someone can presumably add further conditionals to \
allow for yearly, quarterly and weekly. Suggest changing option format to \
e.g. BarChart\[Rule]{True, \"Month\"} in a later version.\
\>", "Text",
 CellChangeTimes->{{3.477825992800086*^9, 3.477825994381529*^9}, {
  3.479549630900161*^9, 3.479549651192206*^9}}],

Cell["\<\
0.4 Tried to make major and minor left and right ticks align better. Mixed \
success. This is necessary for better looking grid lines.\
\>", "Text",
 CellChangeTimes->{{3.477826014525745*^9, 3.477826027203691*^9}}],

Cell["\<\
0.3 Color scheme is now taken from PlotOptions rather than an being an \
argument.
This is the way it is because I prefer having tick marks in black. Therefore \
only tick mark labels and frame can be colored.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 ShowGroupOpener->True,
 CellChangeTimes->{{3.4619279658858337`*^9, 3.461927969037372*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BeginPackage", "[", "\"\<TwoAxisDateListPlot`\>\"", "]"}], ";"}], 
  "\n", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Exported", " ", "symbols", " ", "added", " ", "here", " ", "with", " ", 
    RowBox[{"SymbolName", "::", "usage"}]}], " ", "*)"}], " ", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TwoAxisDateListPlot", "::", "usage"}], "=", 
   "\"\<TwoAxisDateListPlot[list1, list2, options] will generate a two axis \
DateListPlot, i.e. a plot with the left y-axis showing the y values of list1 \
and the right y-axis showing the y values of list2. \\\"options\\\" are the \
same as DateListPlot minus Axes related options, Frame, and Ticks and \
TicksStyle\>\""}], ";"}]}], "InputOnly",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Unprotect", "[", "TwoAxisDateListPlot", "]"}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Implementation", " ", "of", " ", "the", " ", "package"}], " ", 
   "*)"}]}]}], "InputOnly",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "TwoAxisDateListPlot", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", 
    RowBox[{"TwoAxisDateListPlot", ",", " ", "ReadProtected"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SyntaxInformation", "[", "TwoAxisDateListPlot", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"\"\<ArgumentsPattern\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_", ",", 
        RowBox[{"OptionsPattern", "[", "]"}]}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "TwoAxisDateListPlot", "]"}], "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"Options", "[", "DateListPlot", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"BarChart", "\[Rule]", "False"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"TwoAxisDateListPlot", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ";"}]}], "InputOnly",
 InitializationCell->True,
 CellChangeTimes->{{3.479495487741953*^9, 3.479495492146654*^9}, {
  3.4794999225871572`*^9, 3.4794999241782827`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeTicks", "[", "data_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"divisions", ",", "tmp1", ",", "tmp2"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"divisions", "=", 
      RowBox[{"FindDivisions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Min", "[", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], ",", 
          
          RowBox[{"Max", "[", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"5", ",", "5"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"{", 
          RowBox[{"#", ",", "#", ",", 
           RowBox[{"{", 
            RowBox[{"0.00625", ",", "0."}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"GrayLevel", "[", "0.`", "]"}], ",", 
             RowBox[{"AbsoluteThickness", "[", "0.125`", "]"}]}], "}"}]}], 
          "}"}], "]"}], "&"}], "/@", 
       RowBox[{"First", "[", "divisions", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"{", 
          RowBox[{"#", ",", "\"\<\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"0.00375", ",", "0."}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"GrayLevel", "[", "0.`", "]"}], ",", 
             RowBox[{"AbsoluteThickness", "[", "0.125`", "]"}]}], "}"}]}], 
          "}"}], "]"}], "&"}], "/@", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Rest", "[", "divisions", "]"}], "]"}], ",", 
         RowBox[{"First", "[", "divisions", "]"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"First", "@", 
           RowBox[{
           "divisions", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{"Last", "@", 
           RowBox[{
           "divisions", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}]}], "}"}], "}"}], ",", "tmp1", ",", 
       "tmp2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "InputOnly",
 InitializationCell->True,
 CellChangeTimes->{{3.4794992057487087`*^9, 3.479499218026198*^9}, {
  3.4794992904642897`*^9, 3.4794992941038923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoAxisDateListPlot", "[", 
   RowBox[{"line_List", ",", "bar_List", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"plotStyleOptions", "=", 
       RowBox[{"OptionValue", "[", "PlotStyle", "]"}]}], ",", "userOptions", 
      ",", "defaultOptions", ",", "color1", ",", "color2", ",", "leftTicks", 
      ",", "rightTicks", ",", "tmp1", ",", "len", ",", "newTicks", ",", 
      "plotRange", ",", "newBar", ",", "zero", ",", "bars", ",", "prolog", 
      ",", "newPlotStyle"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"get", " ", "options"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"userOptions", "=", 
      RowBox[{"FilterRules", "[", 
       RowBox[{
        RowBox[{"{", "opts", "}"}], ",", 
        RowBox[{"Options", "[", "DateListPlot", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"defaultOptions", "=", 
      RowBox[{"FilterRules", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Options", "[", "TwoAxisDateListPlot", "]"}], "}"}], ",", 
        RowBox[{"Options", "[", "DateListPlot", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
        "set", " ", "colors", " ", "for", " ", "plot", " ", "and", " ", 
         "left"}], " ", "&"}], " ", "right", " ", "ticks"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"plotStyleOptions", "===", "Automatic"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"color1", "=", 
         RowBox[{"ColorData", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"color2", "=", 
         RowBox[{"ColorData", "[", 
          RowBox[{"1", ",", "2"}], "]"}]}], ";"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"color1", "=", 
         RowBox[{"First", "@", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cases", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"First", "[", "plotStyleOptions", "]"}], "}"}], ",", 
               RowBox[{
               "_RGBColor", "|", "__GrayLevel", "|", "__Hue", "|", 
                "__CMYKColor"}], ",", "\[Infinity]"}], "]"}], ",", 
             RowBox[{"ColorData", "[", 
              RowBox[{"1", ",", "1"}], "]"}]}], "}"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"color2", "=", 
         RowBox[{"First", "@", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cases", "[", 
              RowBox[{
               RowBox[{"Rest", "[", "plotStyleOptions", "]"}], ",", 
               RowBox[{
               "_RGBColor", "|", "__GrayLevel", "|", "__Hue", "|", 
                "__CMYKColor"}], ",", "\[Infinity]"}], "]"}], ",", 
             RowBox[{"ColorData", "[", 
              RowBox[{"1", ",", "2"}], "]"}]}], "}"}], "]"}]}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"extract", " ", "ticks"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"leftTicks", "=", 
      RowBox[{"makeTicks", "[", "line", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rightTicks", "=", 
      RowBox[{"makeTicks", "[", "bar", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "make", " ", "new", " ", "ticks", " ", "and", " ", "new", " ", "scaled",
        " ", "range", " ", "and", " ", "then", " ", "color", " ", "tick", " ",
        "labels"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"newTicks", "=", 
      RowBox[{"Apply", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Rescale", "[", 
            RowBox[{
             RowBox[{"N", "@", "#1"}], ",", 
             RowBox[{"First", "@", "rightTicks"}], ",", 
             RowBox[{"First", "@", "leftTicks"}]}], "]"}], ",", "##2"}], 
          "}"}], "&"}], ",", 
        RowBox[{"Rest", "@", "rightTicks"}], ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newTicks", "=", 
      RowBox[{"newTicks", "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x_", ",", 
          RowBox[{"y_", "?", "NumericQ"}], ",", "a_", ",", "b_"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"y", ",", "color2"}], "]"}], ",", "a", ",", "b"}], 
         "}"}]}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "rescale", " ", "the", " ", "bar", " ", "data", " ", "and", " ", "find",
        " ", "the", " ", "zero"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"newBar", "=", 
      RowBox[{"Apply", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#1", ",", 
           RowBox[{"Rescale", "[", 
            RowBox[{"#2", ",", 
             RowBox[{"First", "@", "rightTicks"}], ",", 
             RowBox[{"First", "@", "leftTicks"}]}], "]"}]}], "}"}], "&"}], 
        ",", "bar", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"zero", "=", 
      RowBox[{"Rescale", "[", 
       RowBox[{"0", ",", 
        RowBox[{"First", "@", "rightTicks"}], ",", 
        RowBox[{"First", "@", "leftTicks"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"plotRange", "=", 
      RowBox[{"First", "@", "leftTicks"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"leftTicks", "=", 
      RowBox[{
       RowBox[{"Rest", "@", "leftTicks"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x_", ",", 
          RowBox[{"y_", "?", "NumericQ"}], ",", "a_", ",", "b_"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"y", ",", "color1"}], "]"}], ",", "a", ",", "b"}], 
         "}"}]}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"do", " ", "bar", " ", "calculation"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "\"\<BarChart\>\"", "]"}], "\[Equal]", 
        "True"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"work", " ", "out", " ", "new", " ", "plot", " ", "styles"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Which", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"plotStyleOptions", "===", "Automatic"}], ",", 
          RowBox[{"newPlotStyle", "=", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", 
             RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Length", "[", "plotStyleOptions", "]"}], "\[LessEqual]", 
           "1"}], ",", 
          RowBox[{"newPlotStyle", "=", 
           RowBox[{"Flatten", "@", 
            RowBox[{"{", 
             RowBox[{"plotStyleOptions", ",", 
              RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Length", "[", "plotStyleOptions", "]"}], ">", "1"}], ",", 
          
          RowBox[{
           RowBox[{"newPlotStyle", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "plotStyleOptions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "plotStyleOptions", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"Opacity", "[", "0", "]"}]}], "}"}], "]"}]}], 
             "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "assume", " ", "data", " ", "is", " ", "dated", " ", "the", " ", 
          "end", " ", "of", " ", "the", " ", 
          RowBox[{"month", ".", " ", "Add"}], " ", "a", " ", "start", " ", 
          "of", " ", "month", " ", "date", " ", "for", " ", "the", " ", 
          "rectangle", " ", "x", " ", "coordinates"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"bars", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"AbsoluteTime", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"#", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"#", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                  "1"}], "}"}], "]"}], ",", 
               RowBox[{"Min", "[", 
                RowBox[{"{", 
                 RowBox[{"zero", ",", 
                  RowBox[{
                  "#", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}]}], "}"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"AbsoluteTime", "[", 
                RowBox[{
                "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}], ",", 
               RowBox[{"Max", "[", 
                RowBox[{"{", 
                 RowBox[{"zero", ",", 
                  RowBox[{
                  "#", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}]}], "}"}], "]"}]}], "}"}]}], 
            "]"}], "&"}], "/@", "newBar"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "prolog", " ", "options", " ", "to", " ", "make", " ", "the", " ", 
          "bars", " ", "to", " ", "display", " ", "in", " ", "the", " ", 
          "plot"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"prolog", "=", 
         RowBox[{"{", 
          RowBox[{"color2", ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", 
             RowBox[{"Thin", ",", "White"}], "]"}], "]"}], ",", "bars"}], 
          "}"}]}], ";"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"else", " ", "BarChart"}], "\[Rule]", "False"}], " ", "*)"}],
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newPlotStyle", "=", "plotStyleOptions"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"prolog", "=", 
         RowBox[{"{", "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"DateListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"line", ",", "newBar"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "zero"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Prolog", "\[Rule]", "prolog"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "Automatic", ",", "newTicks", ",", "Automatic", ",", "leftTicks"}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "plotRange"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "newPlotStyle"}], ",", 
       "\[IndentingNewLine]", "userOptions", ",", "\[IndentingNewLine]", 
       "defaultOptions"}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "InputOnly",
 InitializationCell->True,
 CellChangeTimes->{{3.4794955106380663`*^9, 3.4794955132892113`*^9}, {
   3.479495625563127*^9, 3.479495639465658*^9}, 3.479495780561468*^9, {
   3.47949655997173*^9, 3.479496567139649*^9}, {3.479498352890283*^9, 
   3.4794983978446817`*^9}, {3.479498527730097*^9, 3.479498642304809*^9}, 
   3.479498778503654*^9, {3.4794989479278297`*^9, 3.47949895336896*^9}, {
   3.479499007921731*^9, 3.479499012285757*^9}, {3.479499059799427*^9, 
   3.479499066716095*^9}, {3.479499360444776*^9, 3.479499367577455*^9}, {
   3.479499491656973*^9, 3.479499530063264*^9}, {3.479499624796606*^9, 
   3.479499627355916*^9}, {3.479499666278812*^9, 3.479499714097086*^9}, {
   3.479549396634495*^9, 3.479549403969677*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"End", "[", "]"}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", "TwoAxisDateListPlot", "]"}], ";"}], 
  "\n"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "InputOnly",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section",
 ShowGroupOpener->True,
 CellChangeTimes->{{3.4619279579350157`*^9, 3.461927959053739*^9}}],

Cell[CellGroupData[{

Cell["Usage", "Subsection",
 CellChangeTimes->{{3.479549448121922*^9, 3.479549455571665*^9}}],

Cell["\<\
TwoAxisDateListPlot[data1, data2] makes a DateListPlot with ticks for data2 \
on the left hand side of the frame and ticks for data1 on the right hand side \
of the frame.\
\>", "Text",
 CellChangeTimes->{{3.47954945903161*^9, 3.479549527605218*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make some data", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"some", " ", "monthly", " ", "bar", " ", "data"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"barData", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "2", ",", "29"}], "}"}], ",", "136243"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "3", ",", "31"}], "}"}], ",", "126421"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "4", ",", "30"}], "}"}], ",", "127977"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "5", ",", "31"}], "}"}], ",", "94196"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "6", ",", "30"}], "}"}], ",", "75707"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "7", ",", "31"}], "}"}], ",", 
        RowBox[{"-", "88075"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "8", ",", "31"}], "}"}], ",", "87168"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "9", ",", "30"}], "}"}], ",", "112187"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "10", ",", "31"}], "}"}], ",", 
        RowBox[{"-", "128929"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "11", ",", "30"}], "}"}], ",", "141728"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2008", ",", "12", ",", "31"}], "}"}], ",", "211527"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "1", ",", "31"}], "}"}], ",", "180490"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "2", ",", "28"}], "}"}], ",", 
        RowBox[{"-", "270948"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "3", ",", "31"}], "}"}], ",", "296843"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "4", ",", "30"}], "}"}], ",", "317947"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "5", ",", "31"}], "}"}], ",", "337230"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "6", ",", "30"}], "}"}], ",", "378943"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "7", ",", "31"}], "}"}], ",", "292226"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "8", ",", "31"}], "}"}], ",", 
        RowBox[{"-", "219731"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "9", ",", "30"}], "}"}], ",", "282828"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "10", ",", "31"}], "}"}], ",", "169374"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2009", ",", "11", ",", "30"}], "}"}], ",", "244013"}], 
       "}"}]}], "}"}]}], ";"}]}]], "InputOnly",
 InitializationCell->True,
 CellChangeTimes->{3.4778482227312317`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"apple", "=", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<AAPL\>\"", ",", 
     RowBox[{"DatePlus", "[", 
      RowBox[{"-", "720"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dow", "=", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<^DJI\>\"", ",", 
     RowBox[{"DatePlus", "[", 
      RowBox[{"-", "720"}], "]"}]}], "]"}]}], ";"}]}], "InputOnly",
 InitializationCell->True,
 CellChangeTimes->{
  3.479495399748547*^9, {3.4794995789685087`*^9, 3.479499586574148*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make some plots", "Subsection"],

Cell["Default case.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.479549368542832*^9, 3.479549412103805*^9}]
}, Open  ]],

Cell["\<\
Add some tick styling but any color directives in the tick styling are \
removed from the y axes:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow", ",", "\[IndentingNewLine]", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Orange", ",", 
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", "12", 
      ",", "Bold"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  FrameTicksStyle->Directive[
    RGBColor[1, 0.5, 0], FontFamily -> "Helvetica", 12, Bold],
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.479549376026703*^9, 3.479549417637443*^9, 
  3.4795495391183453`*^9}]
}, Open  ]],

Cell["\<\
Add some plot styling and frame tick styling:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Thick", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue", ",", "Dashed"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "10", 
          ",", "Plain"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", 
          "12", ",", "Plain"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "12", 
          ",", "Bold"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "12", 
          ",", "Bold"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Dashing[{Small, Small}], 
    LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0, 0, 1], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0, 0, 1], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0, 0, 1], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0, 0, 1], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0, 0, 1], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  FrameTicksStyle->{{
     Directive[FontFamily -> "Times", 10, Plain], 
     Directive[FontFamily -> "Helvetica", 12, Plain]}, {
     Directive[FontFamily -> "Times", 12, Bold], 
     Directive[FontFamily -> "Times", 12, Bold]}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.4795495485502977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Dashed"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "10", 
          ",", "Plain"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", 
          "12", ",", "Plain"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "12", 
          ",", "Bold"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", "12", 
          ",", "Bold"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
    Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  FrameTicksStyle->{{
     Directive[FontFamily -> "Times", 10, Plain], 
     Directive[FontFamily -> "Helvetica", 12, Plain]}, {
     Directive[FontFamily -> "Times", 12, Bold], 
     Directive[FontFamily -> "Times", 12, Bold]}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.4795495597157993`*^9}]
}, Open  ]],

Cell["Specifying a single color produces an undesirable result.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow", ",", "\[IndentingNewLine]", 
   RowBox[{"FrameStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Black", ",", "Red", ",", "Black", ",", "Green"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", "12", 
      ",", "Bold"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt
mVBDnwAhoQ8lIUACQ4cUMqEIBAgTegBxBJGiu+7Me97zIfOF58dt733vOfd/
702DQeO7Dy1tMpkCpUym0L+h3/MfisOGhX7vD7YF0frWj8VhXYsmV93+Bdjx
WZBD2KXBkBAHsoIc/aBber2yQ0Nsefoj27+Kcnv9CcVhwdpFk8PBxidBDmHV
eqjv+S7IcUeeNgz/AGx7PIHjzQY760wsDluxPPgrArs7T2T/B8E+Z5Ah3BgW
YtPKiex/DdhVaxL7rzE8xN4Ok6i3FzgwNsgRIYFnUd+SEOTu6fWiHzRAuf3I
JI73COV+22S2j0a5eXSQ64f+4yDYtiTIoebduoKdhyZz/L1gd3GQNzjbVrj4
Hdg6IqI4rHXo9wT9OxYGOTcn+PsI5a6MCM6nM8q9dyLoRwNwwDylOCzY23pn
EtizL8i/NwyPO/I52vtvTqEeh+itEsn+eovef0bSvwSwLy2SejqATUWR1NtE
9FacyvbvgB1tpnK8baJ34FSu93tgS2GQH4bs2g199vLTSpQbrabR7+WiP3wa
9aZgff2zpnH8eRIPZQ2u15uo725h6PhgXz+D8+kr8TDToJ+rwNbtQf4mZNg9
9OdtGsX1TAIHekexvYxviYqi3qaif0sU9ZVHuXEhinrag809p9OfR4h329Tp
1HdB9KcoS764z07n/DqAHREzqOc22JU0g+v9jax/3gzqOyV6XwQ5PBRgVSV+
/zGzOOxoMNziFkp+rZvJ8gzxM2em+i96n81U/yX/GkSTJ4nef0fTvw2Yjykr
mvl/Gmz9LZp+2sCOerPozymwq2uQG4UE+LF/eL+dpfOV/eHXWez/M5QbtWdT
/zqwp9Ns6v8T7B8/m/lYCDavmE2/loDdNWOYb++Cfe1jON+qon9sDNdnluhf
FuRQ+rT9VvQfjqHfLcXfdnPox06Jh1FzdD+ReFg8h/VHgo2Dc9jfKInne3O4
nz0Tf4fPpZ6H4m/8XPrjkXg4MJfx9FL2t9tz1W+wyTyPXEv2t9h5HD9e4jl9
HvvfI/pvzOP+IPFnqTyfevaC7R/M5/hWiQf/fPpzQuK3wgLub4Vg53tBDk2v
wrtg91cLNJ7Fz2sLOF6mfC/KxbL86SDobRnL/eAJ2DsglutfFfUD0bG6f6Pc
eCWO9ed9DT+bxzEepoD9feO4/k8HQv+MOPp3xAH927R8Ner7mrjo19coN/V2
UV8q2lsNF+dbHeWOzVoeCXadd9G/cmBLj3jGv70//IyM1/UPh/7keNbvMgD6
8+P1+9gP+v+I53p17At/Jy/kesSA3RsWsr9Pe0P/mYXMj2/BphcLGY8twNa3
F3H/bo323sRF1OfC+IHsRfq9hl7L74vo/xTUt1sWc/yJ0Gd8uph+9UO5+fRi
+r8KbHuymONfx/jOuks43w9Ef5cl9DMW7PtmCfeHmmBHYInGTx/4++ZSzvel
6O+4lPN5G3oD45Zy/kcwH8vypWx/G+WeGss0/sD+sGXUdwj1zWOWsb9zmJ9t
6TKuxwnx36v148CmdgnU+xz6rCMTmH87wY5FCXpewfxdmQn0p47ov5ug/aHc
Pmw5/S0PNlzLOd/JYM/+5bp/94L+W8vZvn5P6H99hX6vwO4FK/S8AD2+vSs4
v90SHzdW8HvhFb3vr2R+NAYH9qxkfn2I+pbrK/V8hnL7a6u4/i/ARutV1Fsg
er9cpecvlNuurtLvn/j56mru92Xgt9u6muuzQOKh/+oS+kzRq+lvPMpdZdaw
3INyb7M11HtF9PdZUyI/LNO1fID4vVXbG2B/47X0czz8Nfday/VNANumraX/
7cHuc2v1vAa2dndz/0sGO6a4S6yXa6Ob8dQbHHjpVv2y3pMSdf2g37M+kfMN
A/tzE5mvXtQ3P0/k+jYVf99ap+1lP3Cv4/wby3pnr6O/P4vep1q/l+itv57z
vYT4cX2yXr+fYPvj9Rxvfg/orbOB5ako93TewPnXED+dJdn5ywbG9wiwu1YS
83+76O2QpP3Leo9Loj82ya+EJOqLQX1v9Y30ww8O2Dayv49R3zJ6I+N9sMTr
ko2cf13Ej3FoY4l4NH+czP7ckv8jkjm/HyReFybr+Uj2r4xkrk++xOudZPqd
JfEZl8LzQaLE574U7gfLJD5vptCPFInPKps4/xzJn/nKGZLvaZvoh0vWv2iT
jge2VdzM/eUz8bvNZsZnD1n/PVr+p6x/4WbqkfVxlN/C/Jf+XK22cP9sI36H
b6GfPdDefmUL1/ck1t8ou5Xr01D0t9jKfGsi8dtvK+O/uvg9U8v/QLm79DaO
XyD7VdNtnN992W/7bKPfX2N9rFHbqH842LFlG/UOBQcabdf28j3ruZ3+ueV7
PHU7830t2EjZzv4myPf47HbqTUO5rdsO3W/Bzogd+v0Gu5N20N+maO/L28F4
a4bvvemltv8L7Jro0fvHl/B3nUf3O5QHcjx6PkW55ZnyLbB/7U7Gb5Wv4GfW
Tq73IpTbftup+QZ21tvF8cJR3911l/oNtp7cxfEtYMevu5gPTrCr9m6yA+zt
tFu//zgfBcYrv0C58Wg387E5yj0195Qo97ffQ31d5Xw2do/mG9i2bA/9ygP7
qqVyPafL+cyWyv6Xgq2jUjU/5Hy2OFXv63I+O5iq91M5n7VNY3+twPbhaXp/
xHhGfJqeX+Cf50Ca5qPov631V4CdQ/ZyfpvQ3h27l/Wviv70vRpfYNPNvYz/
inK+rJyu8Yn+Aqnp9Kev6PWns/9E0VthH/XfABvv7eN8X4DNu/cxX0fjfGu7
to/jjwc7y+1nfK8Bu1vu1/uInIcH7Gf8VhsEPwv2s78/UO565QDz/yLY2/wA
9ceAA30PsP+pYMsMrV9fzuulMuhfaTmvN8lg/xXB5t4Z/H4+lvO6kaH7F9i5
OUO/16hvapSp7xFga49M7kdeiYfITI5fTvQnZ9L/CNGfn8n4OAO22w+y/iGw
Mfkg95dc0b/hIPUViP4zB5kfhvg54RD77yF+Jh5iPDyU+M05pPcl0fu71pf5
OyxevT+In2u8uj+Ln6e1/JTofeKlP+FYL6PuYc1fsKfLYa7Pc7DtxGHmW13c
r5yBw/QrgHL3m0f0eyX35Y5HGG/7wabxWv4X2PXzEa5fGdz3vDWOcjyTvAeG
HWU8C1vGHOV+3k/u+0uPcn8bA/ZXPaZ+g83tjjH+d8r9c+Qx+rVe7p+LjnE+
kXL/zDzG+Xjk/vnRcfq9TO7zw45z/frLe4TrOPNnk+jff5zxX1nuy7eOU/8l
ea8cfILr8VjeIxac0POk6N97gn4sEv03TnC8LNFf6aSuv9zn557U/Uru86kn
9XwHtl4/yfn9LPpfO8X8ai7vQa1P0Z8wuc/vOsX98VW5z1/Vcpmf8epp+psE
9lhPszxf9Pc/TT2fyPtDmSzWXy16m2VxvYaI3r5ZrC/vDdbpWfoeKu8PpmzO
V94XAo2zS7xnWXplM38PyPvJtGzq+Zu8B27KZjxb5L2yYQ7ZJO+V3XO4H7wu
76tTcrgeVnlf3Zij90d5D/TlcLxseV/9Ipd+d5T3ykm5+j2X9+H1uVxPee8M
5OYy/lbK+9pzbV8H5Z4fz+j7l7y3us/ofiT6s8/oe53of6r1U0R//Tz6lSfv
rWvy6O9leW89laf3AXlvfZzHfCoW/XV8rJ8v+jv76GeUvF8f91H/AfH3F5+e
/0dAf618xv/qkdDfIZ/xthFsHpfP/XIq2P0wn/5/AfZVP0t/t6A/U9hZ+lMJ
bB19ln7OAzuWnNXvt/j7xjnNR3kv/vhcifdo+4hzJfwwFp5jftpEf8Y55uen
YNuH5/U8An3Ooeepd6DojzvP/keI/n3nub+1A5tunef8Y8GuQRcYH+fB3vkX
2N4PDqRd0Pd/sKXoAv01g+0Vf6K//4U+/5yf9D1W/N3zE/2V8WyFyrNEb6uL
nN/fwdadF5lP0p/jykXGz1qwq+wlznc22NtCOQ4c6HdJ74tg49IlPR9IPJe+
rPkp8dz0MuNpH+qb+1zm/rBA/I66zPn1Avv+uqznbYmHxgUs7yTx0LOA6+cQ
/VML9H4g8ZxSwP7Hotzy7hX2dxJs73ZFv5/ww4i4on+vAHuSrujfp0Zh/f9z
lfW/A7snXtX3JLBv3VXub9+DTblXOV4fsPeHa5rP4MDaa1y/HLAl6xr9Hwi2
/3aN+393sFGvkP1NA5tXF1JPB7DtZCHbP5N4/bWQ+dNT9Na+Tj+aid5OypkS
n4+uc75Foremn+NNEL3t/Vzv0qJ3rJ/xmy7580DLB0n+Vyti/Ek8m21Feh6T
+BxVpPsP2jsXFzE/S8l6v3FD/ZP1bntDz1+y3sO1/K7Ea/wNxpe09x64wXwa
J+v9r5v69wKJ1yE3NT9Ef6yWD5b8Sr+p790SrzdvUn8lyfd5t+jvGMn3tFsc
v5vkl/8W/f0S7Khwm/21kXyPUa4s+b77tt7/Re+128zPahKf5e7o+4bEZ8s7
en8TPz13uP/Ul3gtuMP4rC3r/8pdxlNjWf/md+lPb4nXfneZv1+Nhp8Xtf4g
sLfUPX0/AQea3NP7zxjo731Pv59gu3FP7/9g//+0/ku0Nzcq5nhVUG7rUazv
e2BnZLG+54PdycX6/UN76zv3yTVR7rDf1/d9sGvyff2egL0b7ms+gANnlK+C
jc8fMH8rjYW/Ex5QfwTYn/iA4znA5pwHzLdpYN/3D+l/3ljb/wFq2S8P
     "]]}, 
   {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t
I4TaJ7aEVjKJRMQSg4ggmERIRBIj1iAx2fCiMpZY6lbvc57nlz9u/snn+znv
+57fec6znTNvj5sxdHxNg8Hgq2EwqP/q79kPutbm2vP5kysnmwlN78zStbq7
Wo0K9jFb/0U8c1L4b3MTpij25RAfm7mumd96ZmMV8Zxj0S26mJktb83WNfvk
tJnrxjHbvyAesyajqp287/rPbHzvNLP5IfGkCfR3iNnWao6uTfjwxuBVm5id
nxJnz6IJHMweGzELbzdVseEX4syqdqPXDGJ2NP9R195c5M6JqcPs7ke8cuqt
F4kmZt804iZJn5WErBD9kcShG/qtmHpA9GcQj/MP6p08nNlrDtG1ONtH9S+n
MftPIf4gmRSJPvOGEDyfL/qPE5fH/5JpbMHzOXXij+tf3mprzGya9JOuDWhQ
s+PS95mta4mnk7wHG/l9Rxpxbkz/lEdetr/7JnHBO7RBj5l9/nMx3wJm1yHi
z0tC3kxKYfaWEVvUA9eY/RvO07WbHvqAn+jtRdx535bKhJc87kkhXt/ML7Dh
OmZDCXEpfe6zvuIPr87XtR0PCgaO6yX+8N582LuM2TGWmFbTpDDhW7ZnMfGp
f/ZcpnmZLXUX6Nq7NJx/i9nebQH8px+zazRx29oLN/T7jtm7hHguTV9SxWyr
Zcf4ZWZnF2Jlzo/szJ6RxMqd+jRlNiwmTnn0x4U53ZhNScQvL8zR24ZOYnu+
u1DXruY/HVa2kNkXuBD2H89sXEhM1s2e9S2zZSfxdQqPtAETWf9F4rU03XtV
E9i+w0PJvw9/0aDmM2bz/FCs9y/8vG078Smj6/tJK3ncWUB8m6YrOMVs/WmR
rqnh8E3Mjnji+/T5MW/w++6zi+API3jc95zYl0AWjmA2tlmsa97BqyKmm5hd
sYux3gbM3lziEL1t17oZ41nv08Xw92jR+3YYxUMhGaS/6P1nGPZvGrMhhzhg
VPCHN0Ywmx6HIf4ymK0BS3RtI33uViGz4/Ml+P5T/r77+yWI57o8bnlArNJF
0ec8bm+5VNfeVwYM4HFX/6VY7z5m74ylyE8Nmf03L4W/Vog9m/2sa6kBYXeH
nGD29CUObNhp35Zc0T+N2FpBAXBP9EcQO2n6Nr1Ffzrx77S9MzuKP/RZBv8b
Iv4weRnip0T0r1+G/Vku/nBsGfKBzOe6TTxUCapkNk9crmurI6a/vmis2Dd8
OfLJE9F/ZDn8rxOPeyqIlTt17CX6/Vfo2q+Z5CGXxL6rV8D+jcU/UomjKskh
OjD7SlfAH79nNr62EuttJf7ccyXmXyv29BJvVxs+T/TWX6Vr/yX3HCjrs/Ug
Lm5DAThL9I4hHl5GCc7BbCoi/gdtb8QcsWed1Xg+Uvy5K3FftQEHxR++Il6i
HO4D0Ru2Gu93FXv6rYH+KPZXV+c18PdG4s9BxPPJ/IcTgln/IuJIMq+7kp83
767mJmLPjg743z0eNwQSz6L0EziF2WR3QN9wZusOYpUe4h8wOy4Qdy6iBQ2V
eBsWrmsOKmejy//N9pwXjnw+iZ+3J4TD34JE/7nw6nzKer0vwmHfTH7fFrJW
1yaq+vfrOLZvHHEClQ9XrW9Yfz5xY1WvpltZ/3PiYJX/o0az/r+uo/Wq+Dv3
Fds3hvg1lZAv8fO+M8QzyBw5kczGJ+uQ/3/l9y3G9bq2XCkOGMv6BxAHK3sN
G8P2PU18YSAVlJn8vvkRsUrfgT/z87bWGyifqvz4MX/P+dkG+OfQr1n/d8SH
VXyOYX1WH3EStRcfNh/F9m2xUdeuULrqup2/5/5kI/yxK7NvOvF4pcck+jcR
j1X+Ecfsahqha8dVPolm9mrEg1X9W8/2858agfzRSPRvJG6n6slI1mdzE6t2
pdlNXq+hT6SuudX3bMymbyOx3kB+3rqOOFvlx0zRfzQS/Usvft59i9hPJaCW
Yt8Jm+CvB/h5u4N48yb6S2B7uA4Te5S/vQhi/eWb0K90D2T9jTbr2mJqZ/oP
GMn2XUVsV/n1JL/vObgZ+f5PZkPpZvRfy0Xv+7/o2ihVzzqzPl8ycV1a/or7
/D3jjWqO4vct9X6Ff+1j/fbuxJ+Qe70YKXq/Jr5D5WTXMx43Xyfervz1En/f
VnsL+h/Zf6dpC/RniD+M2oJ89DO/bwjbgn6wktnxShTth6rnS5ndnYhVeo0+
Jfq/jEK+bMtsDI2Cviyx964orF/iw9shWtdMKn77MPuPiEa/Gs3rMS+IRv39
jdl5nliFa0kvia+hTl0z0/Z9UZvZOtcJ+3fi9Ti2EQ9S/naV2fe7E/PNlnj6
MQb6H7Ne19YY9MNBPO7NI74/hArGWX7f/xmxKl+VW5nN78TCvsd4fo+T2KQa
9Cey32di4W95zKaqWOgxs79Z39oK+wwTf/2COEfV13Rmy8Ot2P8k9j97qzhd
6zCaBE7lcdenceiXM9lfvDbiqSpe5jLbKuPgv4fEP5vHw55N+X1PP8UU/qlB
ond6POJR/M8USfwvCidrDWZ3k226xtuxmfX4zNswPk/8dco25K/DPG7ZQPyY
2j09mMftx7fBP9w8v//HCdQvqvPMXmbzpAT0b4P4fdvaBPSP0czOtAToW8/s
uZmA+fyZHWu2Y/96cHy6DxFbVT7qzewrI76n9jNxBOttmEj9OLVnr9djdq1M
hL1mD2N7piTCXx4MZ70lieifvmM2v7pD15qp/qyMn7e9twP+0IbZkLwD/XH/
IWzP4h04/9Rjttbdifz9nNnRbSfOUz0trH90NU9htlzbif7+0mC2Z61d6P8H
DGX9XYhV+7DVwuwduQv+4GE9/ot3oT9qy/qdNXdTPbhI+akls+dd4iXkDgG9
2R6GL3ejfuYwmxbuRr3UmK07d6N/nsfv+9onwR82fcn2HZ6Eeu5l+1vmE9dW
8TCDx+3biZ2qP1rK++cqSEL/L++bh+xBPXqF37f9tAf5ajWzM34P7BHKz3vO
7oF/XufvGX7fU91fsf855rjQHxTyuDvWhfn38Pu+XBf0vxD9T11YX5jEV/Re
nPdGM/vn7EX+sfP3zI/34nzeReIvYB/8IVvi7/N9yL8FEl9Z+9Cv1eT3rQ/2
Qc9Z8eeW+9GfDhC9/fdj/IjE3wzih7T9/iESX/f3V5+/mV3NkrGfLUV/32T0
r+0l/qYRx1K6+aOBxF9EMvojyUeexgd0TZWb7B2SH8zEV+h4Vz9c8tnkA4iX
7pJ/1xM/o+3IWMPjjmMHcL6O4HHjRyk476CeTUxBPbjPbA9PwfkrS/LbEeJ2
VM5avc7j3orq8d08bgs+CP9sK/3N6oOY/6nU39SD6Ce2iv4yYtWuTzrP75te
S6V+QiXcI8y+A6noj6v4eaM3FXq9ko/rHyJ/pHT75hLR2+MQ5jdK/dpP/FL1
j6FSH4oOIb/FSD9T53D1eV3qb9dqdkn9/eow+uuT0h9cPYx6mCX1zO+IrvUi
96zIZHZ3PoLzZZTUtyDiVHW+PsdsXHQE/eNLZleNtOr1S/3tmIbn/y76A9NQ
76U/MtvTUG/mMNt2pKF+jJX+oP1R5OMA8YdhR5GP/aSfnEecTHjqhtS3hKM4
3zySfvjcUdTro+IPlmNY/2Dpb0KIe3SnvzPS38QRq+PefNlvb/4x2EfqpXP2
ccp/qp+uI/sfcxz+UIvHDbnHcZ5sLfv/5Djy/9+kHhvdsOcdjhdflBvxK/5n
PO3GfH1E7yM3+oFC0ds6HfXue7H3Z+nwh23iD6fSET8DpR/zpaO+HGJ2tsjA
/Usos+eTDPS7SdyPGGZkYP6LzI7fiIOUgN+kP296Auerq9KfayfQf+5lNk49
gf1ryf22ZeMJ5K/20p+/mYl6G8bs34f4T/W+U/rzb4nV9p6yM9vWZaLfn8bs
PJqJ8382s+kfJ5Fvk5itE4i/VvX5G2aH4yTmT2d2Hz6J80SxnI/KiVV7EhDD
bP/3KeT/BnK+WEXcTSXcQaL/IHFTVY8XiP5SYnUdVT9V9DfIQr7tIee35Vmo
5z2ZDQeysP+DmU03shA/Q5mt9bJ1rYvaLxuzo3s21jeM2biPuJV6oBOz5Xo2
zodyvrPXPo3zk9jPZTqN8+R+0T+K+Kja/xr8vvOVHF1rre535HueTjmw/wjR
G5SD/nGD6A3NwfoXM7sNZ3RNtQM2Gfd1IJ6nzjsZoncEsWq3xjQfx3oXnMF5
+w1me+IZ7JeJ2b9dLs6vjZjNQ3ORj3oy2+bmVt+fiP5tubgvuij6Pbnwp2Sx
5+A85Jum/L7jR+KnKl4fiP6tecj3haI/L+//9sv4LA962zK7ZuXrWl4u/S1g
9jrzUQ91OW+eycf9YTmzuSof9byx6H/rLPQOYzZEnUU/Fcxsyj6L+9QgZuvD
s9i/XNHfygN/fMjs/tQDe6eJfU96EJ/1+H7BXkk8W8VzCY+7mp+DPSKYvf2I
VXg0qMHP+08/h/usRB533juH/Qtk9jQpwH3oN6JfK4C9a4r+KQXoF2JF/4YC
zH9V7PvGecSf7Ifx4/Oob/VE/6TzqJdvi3+sPY94yhT9aecxf4H4x4cX8L0f
5D5lPLFKv+vCmJ1rLiDfJzJ7DhGr9uP518yG8gvoxyKZHeMuIn/V4vsa98qL
yL+tmX0pF3Ff2ZjZWHIR+3la7oNevYT1HGP2LiN+ovytndxXJV/C/VcLZnPx
JZwXujM7u13GfAf5fdPey7h/Pc9svXYZ/X5vft5R6wr6zw6it8sV3D/K/ZRv
5BX0Z0/FH64QN1QO9ozZVbMQ8R4net8thD/miT98WYj7CD/Ru7AQ9VLm9/xZ
iHi0MBs6XMX9Rntm0/CriF8js3U+8TNq535JEXtvJ1bXCa2ymI1/v6ZrarmD
X+XnLUOu4Twn9rH/dA315j1mV/w19EtWZtug69D7g9hzznXcb88UvbHXcT8/
S/TmXUf/2ETs90MR+td1st/RRbhPXib7nVMEPctF3+MixFO86Asoxn1jkuz3
FuJL6n7rvNgvqxjzHxC9D4rxfa/obXkDep6J3v7E6vosVe47Hfdv4Dznx/eL
7mZe+E+s6O3rxX287Ldxmrf6/Cb7fdcLveL/3sYlqEdfyX6bS3C+mctsnlyC
+DdKfK0vwX1bFcef4Y1S5Mvh4q8fleK+YLf468RSrAfxFV6K/JLO77uPlKL/
P81s+aAM8T+L2R5chn7nPrNrdRl+/ypm9qaWIR92F/1lZfCfRhLvK8oRrxES
7ynlOD8hvrzl+P3gd9FbvwL3/zXEnj9XYL6HYs/9FbBPjMR7UQX8667EV52b
qCdusXfXm7hvkPtes+sm+v1XZP+v3sT6Jb6cfrdwHvxD9He+hfX8Vfx15C30
y4vFHy7fQj8XIv5b4zbuqxeJ/o638XtLmPhv4G38PpYo/mu/jXqxX+6nX96G
v6WL/7bXoa9c/HeYjvxUn/3PNk/H+bsLszNBx/nmL3K/3vYO9rOH3K9b7qA+
LJX79ZA7yFejxZ/j7iA/Wpl9+XfQv+F+feBdXdum6uFKuV+ffRd6NjB7Y+7i
fn2a/N6VexfnhXhmz8x7yFc5483/A8SVa/U=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameStyle->{
    GrayLevel[0], 
    RGBColor[1, 0, 0], 
    GrayLevel[0], 
    RGBColor[0, 1, 0]},
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  FrameTicksStyle->Directive[FontFamily -> "Helvetica", 12, Bold],
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.4795495663961277`*^9}]
}, Open  ]],

Cell["\<\
I was hoping left and right major ticks would align a bit better so that \
gridlines looked good. This example works okay but overall this feature still \
needs some work.\
\>", "Text",
 CellChangeTimes->{{3.479549587032653*^9, 3.4795495991513157`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "dow", ",", "\[IndentingNewLine]", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", "12", 
      ",", "Bold"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXl8jNcax4fGWiW3rZ102uu6lmIsLdrbmpfq4l6MLQ1Vpm4stU57FU0t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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3417292800, -100}, {3.4172928*^9, -100}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox["6000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["8000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["10000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["12000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["14000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  FrameTicksStyle->Directive[FontFamily -> "Helvetica", 12, Bold],
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, Automatic}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, Automatic}],
  PlotRange->{{3.4172928*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.4795495712924757`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bar charts", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "barData", ",", 
   RowBox[{"BarChart", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479499897202076*^9, 3.479499910793384*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQQGlnkvHXOf/175kTHdASQQWvzS8V2NvWnc5jQQ
f4FbxUvHTseEpxf2g/kFSbUvHRU3FGVM3JgK4guENL101N009/1yWTD/QX77
S8ezZ4DgXzyIv6G756XjZd8kgYhKsHxA7cSXjheVbv+scwSbpzBz2ktHJ6Dx
SoWxIP6BrtkvHUHOuaQLds+EZQteOn5YfszbPCYTxE84tPSlY9AOudbXyRlg
98Wveunotu3z3ysTQsDuq17/0tFyy4myfWw5YPflbnnpWJ+1p2TyejD/QcfO
l45LCmy5rnvmgvgNVfteOrI1TnXunp4Hdt+0wy8dtdvFbp57mA1236YTLx3/
AJ3jeyQc7L7FZ186goyfPw0sP2H/pZeOi1yBDuACu8dg4/WXjieB0lIJWQ4A
s42XPA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3413232000, 150}, {3.413232*^9, 150}],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox[
         RowBox[{"-", "400000.`"}], 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox[
         RowBox[{"-", "200000.`"}], 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["0.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["400000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, None}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, None}],
  PlotRange->{{3.413232*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Prolog->{
    RGBColor[0.6, 0.24, 0.4428931686004542], 
    EdgeForm[
     Directive[
      Thickness[Tiny], 
      GrayLevel[1]]], {
     RectangleBox[
      NCache[{3410812800, 150}, {3.4108128*^9, 150}], 
      NCache[{3413232000, 
        Rational[736243, 4000]}, {3.413232*^9, 184.06075}]], 
     RectangleBox[
      NCache[{3413318400, 150}, {3.4133184*^9, 150}], 
      NCache[{3415910400, 
        Rational[726421, 4000]}, {3.4159104*^9, 181.60525}]], 
     RectangleBox[
      NCache[{3415996800, 150}, {3.4159968*^9, 150}], 
      NCache[{3418502400, 
        Rational[727977, 4000]}, {3.4185024*^9, 181.99425}]], 
     RectangleBox[
      NCache[{3418588800, 150}, {3.4185888*^9, 150}], 
      NCache[{3421180800, 
        Rational[173549, 1000]}, {3.4211808*^9, 173.549}]], 
     RectangleBox[
      NCache[{3421267200, 150}, {3.4212672*^9, 150}], 
      NCache[{3423772800, 
        Rational[675707, 4000]}, {3.4237728*^9, 168.92675}]], 
     RectangleBox[
      NCache[{3423859200, 
        Rational[20477, 160]}, {3.4238592*^9, 127.98125}], 
      NCache[{3426451200, 150}, {3.4264512*^9, 150}]], 
     RectangleBox[
      NCache[{3426537600, 150}, {3.4265376*^9, 150}], 
      NCache[{3429129600, 
        Rational[21474, 125]}, {3.4291296*^9, 171.792}]], 
     RectangleBox[
      NCache[{3429216000, 150}, {3.429216*^9, 150}], 
      NCache[{3431721600, 
        Rational[712187, 4000]}, {3.4317216*^9, 178.04675}]], 
     RectangleBox[
      NCache[{3431808000, 
        Rational[471071, 4000]}, {3.431808*^9, 117.76775}], 
      NCache[{3434400000, 150}, {3.4344*^9, 150}]], 
     RectangleBox[
      NCache[{3434486400, 150}, {3.4344864*^9, 150}], 
      NCache[{3436992000, 
        Rational[23179, 125]}, {3.436992*^9, 185.432}]], 
     RectangleBox[
      NCache[{3437078400, 150}, {3.4370784*^9, 150}], 
      NCache[{3439670400, 
        Rational[811527, 4000]}, {3.4396704*^9, 202.88175}]], 
     RectangleBox[
      NCache[{3439756800, 150}, {3.4397568*^9, 150}], 
      NCache[{3442348800, 
        Rational[78049, 400]}, {3.4423488*^9, 195.1225}]], 
     RectangleBox[
      NCache[{3442435200, 
        Rational[82263, 1000]}, {3.4424352*^9, 82.263}], 
      NCache[{3444768000, 150}, {3.444768*^9, 150}]], 
     RectangleBox[
      NCache[{3444854400, 150}, {3.4448544*^9, 150}], 
      NCache[{3447446400, 
        Rational[896843, 4000]}, {3.4474464*^9, 224.21075}]], 
     RectangleBox[
      NCache[{3447532800, 150}, {3.4475328*^9, 150}], 
      NCache[{3450038400, 
        Rational[917947, 4000]}, {3.4500384*^9, 229.48675}]], 
     RectangleBox[
      NCache[{3450124800, 150}, {3.4501248*^9, 150}], 
      NCache[{3452716800, 
        Rational[93723, 400]}, {3.4527168*^9, 234.3075}]], 
     RectangleBox[
      NCache[{3452803200, 150}, {3.4528032*^9, 150}], 
      NCache[{3455308800, 
        Rational[978943, 4000]}, {3.4553088*^9, 244.73575}]], 
     RectangleBox[
      NCache[{3455395200, 150}, {3.4553952*^9, 150}], 
      NCache[{3457987200, 
        Rational[446113, 2000]}, {3.4579872*^9, 223.0565}]], 
     RectangleBox[
      NCache[{3458073600, 
        Rational[380269, 4000]}, {3.4580736*^9, 95.06725}], 
      NCache[{3460665600, 150}, {3.4606656*^9, 150}]], 
     RectangleBox[
      NCache[{3460752000, 150}, {3.460752*^9, 150}], 
      NCache[{3463257600, 
        Rational[220707, 1000]}, {3.4632576*^9, 220.707}]], 
     RectangleBox[
      NCache[{3463344000, 150}, {3.463344*^9, 150}], 
      NCache[{3465936000, 
        Rational[384687, 2000]}, {3.465936*^9, 192.3435}]], 
     RectangleBox[
      NCache[{3466022400, 150}, {3.4660224*^9, 150}], 
      NCache[{3468528000, 
        Rational[844013, 4000]}, {3.468528*^9, 211.00325}]]}},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3415996800, 3.4159968*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.479549610588296*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "barData", ",", "\[IndentingNewLine]", 
   RowBox[{"BarChart", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", "12", 
      ",", "Bold"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotRangePadding", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Scaled", "[", "0.05", "]"}], ",", 
        RowBox[{"Scaled", "[", "0.02", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Scaled", "[", "0.05", "]"}], ",", 
        RowBox[{"Scaled", "[", "0.05", "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQQGlnkvHXOf/175kTHdASQQWvzS8V2NvWnc5jQQ
f4FbxUvHTseEpxf2g/kFSbUvHRU3FGVM3JgK4guENL101N009/1yWTD/QX77
S8ezZ4DgXzyIv6G756XjZd8kgYhKsHxA7cSXjheVbv+scwSbpzBz2ktHJ6Dx
SoWxIP6BrtkvHUHOuaQLds+EZQteOn5YfszbPCYTxE84tPSlY9AOudbXyRlg
98Wveunotu3z3ysTQsDuq17/0tFyy4myfWw5YPflbnnpWJ+1p2TyejD/QcfO
l45LCmy5rnvmgvgNVfteOrI1TnXunp4Hdt+0wy8dtdvFbp57mA1236YTLx3/
AJ3jeyQc7L7FZ186goyfPw0sP2H/pZeOi1yBDuACu8dg4/WXjieB0lIJWQ4A
s42XPA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3413232000, 150}, {3.413232*^9, 150}],
  BaseStyle->Directive[FontFamily -> "Helvetica", 12, Bold],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox[
         RowBox[{"-", "400000.`"}], 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox[
         RowBox[{"-", "200000.`"}], 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["0.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["400000.`", 
         RGBColor[0.6, 0.24, 0.4428931686004542], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         RGBColor[0.24720000000000014`, 0.24, 0.6], StripOnInput -> False], 
        TraditionalForm], {0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, Automatic}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, Automatic}],
  PlotRange->{{3.413232*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[0.6, 0.24, 0.4428931686004542], 
    EdgeForm[
     Directive[
      Thickness[Tiny], 
      GrayLevel[1]]], {
     RectangleBox[
      NCache[{3410812800, 150}, {3.4108128*^9, 150}], 
      NCache[{3413232000, 
        Rational[736243, 4000]}, {3.413232*^9, 184.06075}]], 
     RectangleBox[
      NCache[{3413318400, 150}, {3.4133184*^9, 150}], 
      NCache[{3415910400, 
        Rational[726421, 4000]}, {3.4159104*^9, 181.60525}]], 
     RectangleBox[
      NCache[{3415996800, 150}, {3.4159968*^9, 150}], 
      NCache[{3418502400, 
        Rational[727977, 4000]}, {3.4185024*^9, 181.99425}]], 
     RectangleBox[
      NCache[{3418588800, 150}, {3.4185888*^9, 150}], 
      NCache[{3421180800, 
        Rational[173549, 1000]}, {3.4211808*^9, 173.549}]], 
     RectangleBox[
      NCache[{3421267200, 150}, {3.4212672*^9, 150}], 
      NCache[{3423772800, 
        Rational[675707, 4000]}, {3.4237728*^9, 168.92675}]], 
     RectangleBox[
      NCache[{3423859200, 
        Rational[20477, 160]}, {3.4238592*^9, 127.98125}], 
      NCache[{3426451200, 150}, {3.4264512*^9, 150}]], 
     RectangleBox[
      NCache[{3426537600, 150}, {3.4265376*^9, 150}], 
      NCache[{3429129600, 
        Rational[21474, 125]}, {3.4291296*^9, 171.792}]], 
     RectangleBox[
      NCache[{3429216000, 150}, {3.429216*^9, 150}], 
      NCache[{3431721600, 
        Rational[712187, 4000]}, {3.4317216*^9, 178.04675}]], 
     RectangleBox[
      NCache[{3431808000, 
        Rational[471071, 4000]}, {3.431808*^9, 117.76775}], 
      NCache[{3434400000, 150}, {3.4344*^9, 150}]], 
     RectangleBox[
      NCache[{3434486400, 150}, {3.4344864*^9, 150}], 
      NCache[{3436992000, 
        Rational[23179, 125]}, {3.436992*^9, 185.432}]], 
     RectangleBox[
      NCache[{3437078400, 150}, {3.4370784*^9, 150}], 
      NCache[{3439670400, 
        Rational[811527, 4000]}, {3.4396704*^9, 202.88175}]], 
     RectangleBox[
      NCache[{3439756800, 150}, {3.4397568*^9, 150}], 
      NCache[{3442348800, 
        Rational[78049, 400]}, {3.4423488*^9, 195.1225}]], 
     RectangleBox[
      NCache[{3442435200, 
        Rational[82263, 1000]}, {3.4424352*^9, 82.263}], 
      NCache[{3444768000, 150}, {3.444768*^9, 150}]], 
     RectangleBox[
      NCache[{3444854400, 150}, {3.4448544*^9, 150}], 
      NCache[{3447446400, 
        Rational[896843, 4000]}, {3.4474464*^9, 224.21075}]], 
     RectangleBox[
      NCache[{3447532800, 150}, {3.4475328*^9, 150}], 
      NCache[{3450038400, 
        Rational[917947, 4000]}, {3.4500384*^9, 229.48675}]], 
     RectangleBox[
      NCache[{3450124800, 150}, {3.4501248*^9, 150}], 
      NCache[{3452716800, 
        Rational[93723, 400]}, {3.4527168*^9, 234.3075}]], 
     RectangleBox[
      NCache[{3452803200, 150}, {3.4528032*^9, 150}], 
      NCache[{3455308800, 
        Rational[978943, 4000]}, {3.4553088*^9, 244.73575}]], 
     RectangleBox[
      NCache[{3455395200, 150}, {3.4553952*^9, 150}], 
      NCache[{3457987200, 
        Rational[446113, 2000]}, {3.4579872*^9, 223.0565}]], 
     RectangleBox[
      NCache[{3458073600, 
        Rational[380269, 4000]}, {3.4580736*^9, 95.06725}], 
      NCache[{3460665600, 150}, {3.4606656*^9, 150}]], 
     RectangleBox[
      NCache[{3460752000, 150}, {3.460752*^9, 150}], 
      NCache[{3463257600, 
        Rational[220707, 1000]}, {3.4632576*^9, 220.707}]], 
     RectangleBox[
      NCache[{3463344000, 150}, {3.463344*^9, 150}], 
      NCache[{3465936000, 
        Rational[384687, 2000]}, {3.465936*^9, 192.3435}]], 
     RectangleBox[
      NCache[{3466022400, 150}, {3.4660224*^9, 150}], 
      NCache[{3468528000, 
        Rational[844013, 4000]}, {3.468528*^9, 211.00325}]]}},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3415996800, 3.4159968*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.479549616586836*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoAxisDateListPlot", "[", 
  RowBox[{"apple", ",", "barData", ",", "\[IndentingNewLine]", 
   RowBox[{"BarChart", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", "12", 
      ",", "Bold"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRangePadding", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Scaled", "[", "0.05", "]"}], ",", 
        RowBox[{"Scaled", "[", "0.02", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Scaled", "[", "0.05", "]"}], ",", 
        RowBox[{"Scaled", "[", "0.05", "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}], ",", "Orange"}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxVmWd41FUWxgcQQZqzK1XaoPsonQFE91lFJnRdXYfeooz0zlgpIfAPEAgt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     "]]}, 
   {RGBColor[1, 0.5, 0], Opacity[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQQGlnkvHXOf/175kTHdASQQWvzS8V2NvWnc5jQQ
f4FbxUvHTseEpxf2g/kFSbUvHRU3FGVM3JgK4guENL101N009/1yWTD/QX77
S8ezZ4DgXzyIv6G756XjZd8kgYhKsHxA7cSXjheVbv+scwSbpzBz2ktHJ6Dx
SoWxIP6BrtkvHUHOuaQLds+EZQteOn5YfszbPCYTxE84tPSlY9AOudbXyRlg
98Wveunotu3z3ysTQsDuq17/0tFyy4myfWw5YPflbnnpWJ+1p2TyejD/QcfO
l45LCmy5rnvmgvgNVfteOrI1TnXunp4Hdt+0wy8dtdvFbp57mA1236YTLx3/
AJ3jeyQc7L7FZ186goyfPw0sP2H/pZeOi1yBDuACu8dg4/WXjieB0lIJWQ4A
s42XPA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{3413232000, 150}, {3.413232*^9, 150}],
  BaseStyle->Directive[FontFamily -> "Helvetica", 12, Bold],
  Frame->True,
  FrameTicks->{{{{50., 
       FormBox[
        StyleBox[
         RowBox[{"-", "400000.`"}], 
         RGBColor[1, 0.5, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox[
         RowBox[{"-", "200000.`"}], 
         RGBColor[1, 0.5, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["0.`", 
         RGBColor[1, 0.5, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200000.`", 
         RGBColor[1, 0.5, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["400000.`", 
         RGBColor[1, 0.5, 0], StripOnInput -> False], TraditionalForm], {
       0.00625, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {62.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {75., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {87.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {112.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {125., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {137.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {162.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {175., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {187.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {212.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {225., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {237.5, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}, {{50., 
       FormBox[
        StyleBox["50.`", 
         GrayLevel[0], StripOnInput -> False], TraditionalForm], {0.00625, 
       0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {100., 
       FormBox[
        StyleBox["100.`", 
         GrayLevel[0], StripOnInput -> False], TraditionalForm], {0.00625, 
       0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {150., 
       FormBox[
        StyleBox["150.`", 
         GrayLevel[0], StripOnInput -> False], TraditionalForm], {0.00625, 
       0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {200., 
       FormBox[
        StyleBox["200.`", 
         GrayLevel[0], StripOnInput -> False], TraditionalForm], {0.00625, 
       0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {250., 
       FormBox[
        StyleBox["250.`", 
         GrayLevel[0], StripOnInput -> False], TraditionalForm], {0.00625, 
       0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {60., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {70., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {80., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {90., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {110., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {120., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {130., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {140., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {160., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {170., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {180., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {190., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {210., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {220., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {230., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}, {240., 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        GrayLevel[0.], 
        AbsoluteThickness[0.125]}}}}, {{{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3439756800, 3.4397568*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3471292800, 3.4712928*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3415996800, 3.4159968*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3423859200, 3.4238592*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3431808000, 3.431808*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3447532800, 3.4475328*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3455395200, 3.4553952*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3463344000, 3.463344*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3479068800, 3.4790688*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  GridLines->NCache[{{{3439756800, 
       GrayLevel[0.8]}, {3471292800, 
       GrayLevel[0.8]}}, Automatic}, {{{3.4397568*^9, 
       GrayLevel[0.8]}, {3.4712928*^9, 
       GrayLevel[0.8]}}, Automatic}],
  PlotRange->{{3.413232*^9, 3.4794144*^9}, {50, 250}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{
    RGBColor[1, 0.5, 0], 
    EdgeForm[
     Directive[
      Thickness[Tiny], 
      GrayLevel[1]]], {
     RectangleBox[
      NCache[{3410812800, 150}, {3.4108128*^9, 150}], 
      NCache[{3413232000, 
        Rational[736243, 4000]}, {3.413232*^9, 184.06075}]], 
     RectangleBox[
      NCache[{3413318400, 150}, {3.4133184*^9, 150}], 
      NCache[{3415910400, 
        Rational[726421, 4000]}, {3.4159104*^9, 181.60525}]], 
     RectangleBox[
      NCache[{3415996800, 150}, {3.4159968*^9, 150}], 
      NCache[{3418502400, 
        Rational[727977, 4000]}, {3.4185024*^9, 181.99425}]], 
     RectangleBox[
      NCache[{3418588800, 150}, {3.4185888*^9, 150}], 
      NCache[{3421180800, 
        Rational[173549, 1000]}, {3.4211808*^9, 173.549}]], 
     RectangleBox[
      NCache[{3421267200, 150}, {3.4212672*^9, 150}], 
      NCache[{3423772800, 
        Rational[675707, 4000]}, {3.4237728*^9, 168.92675}]], 
     RectangleBox[
      NCache[{3423859200, 
        Rational[20477, 160]}, {3.4238592*^9, 127.98125}], 
      NCache[{3426451200, 150}, {3.4264512*^9, 150}]], 
     RectangleBox[
      NCache[{3426537600, 150}, {3.4265376*^9, 150}], 
      NCache[{3429129600, 
        Rational[21474, 125]}, {3.4291296*^9, 171.792}]], 
     RectangleBox[
      NCache[{3429216000, 150}, {3.429216*^9, 150}], 
      NCache[{3431721600, 
        Rational[712187, 4000]}, {3.4317216*^9, 178.04675}]], 
     RectangleBox[
      NCache[{3431808000, 
        Rational[471071, 4000]}, {3.431808*^9, 117.76775}], 
      NCache[{3434400000, 150}, {3.4344*^9, 150}]], 
     RectangleBox[
      NCache[{3434486400, 150}, {3.4344864*^9, 150}], 
      NCache[{3436992000, 
        Rational[23179, 125]}, {3.436992*^9, 185.432}]], 
     RectangleBox[
      NCache[{3437078400, 150}, {3.4370784*^9, 150}], 
      NCache[{3439670400, 
        Rational[811527, 4000]}, {3.4396704*^9, 202.88175}]], 
     RectangleBox[
      NCache[{3439756800, 150}, {3.4397568*^9, 150}], 
      NCache[{3442348800, 
        Rational[78049, 400]}, {3.4423488*^9, 195.1225}]], 
     RectangleBox[
      NCache[{3442435200, 
        Rational[82263, 1000]}, {3.4424352*^9, 82.263}], 
      NCache[{3444768000, 150}, {3.444768*^9, 150}]], 
     RectangleBox[
      NCache[{3444854400, 150}, {3.4448544*^9, 150}], 
      NCache[{3447446400, 
        Rational[896843, 4000]}, {3.4474464*^9, 224.21075}]], 
     RectangleBox[
      NCache[{3447532800, 150}, {3.4475328*^9, 150}], 
      NCache[{3450038400, 
        Rational[917947, 4000]}, {3.4500384*^9, 229.48675}]], 
     RectangleBox[
      NCache[{3450124800, 150}, {3.4501248*^9, 150}], 
      NCache[{3452716800, 
        Rational[93723, 400]}, {3.4527168*^9, 234.3075}]], 
     RectangleBox[
      NCache[{3452803200, 150}, {3.4528032*^9, 150}], 
      NCache[{3455308800, 
        Rational[978943, 4000]}, {3.4553088*^9, 244.73575}]], 
     RectangleBox[
      NCache[{3455395200, 150}, {3.4553952*^9, 150}], 
      NCache[{3457987200, 
        Rational[446113, 2000]}, {3.4579872*^9, 223.0565}]], 
     RectangleBox[
      NCache[{3458073600, 
        Rational[380269, 4000]}, {3.4580736*^9, 95.06725}], 
      NCache[{3460665600, 150}, {3.4606656*^9, 150}]], 
     RectangleBox[
      NCache[{3460752000, 150}, {3.460752*^9, 150}], 
      NCache[{3463257600, 
        Rational[220707, 1000]}, {3.4632576*^9, 220.707}]], 
     RectangleBox[
      NCache[{3463344000, 150}, {3.463344*^9, 150}], 
      NCache[{3465936000, 
        Rational[384687, 2000]}, {3.465936*^9, 192.3435}]], 
     RectangleBox[
      NCache[{3466022400, 150}, {3.4660224*^9, 150}], 
      NCache[{3468528000, 
        Rational[844013, 4000]}, {3.468528*^9, 211.00325}]]}},
  Ticks->{{{
      NCache[3439756800, 3.4397568*^9], 
      FormBox["\"2009\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3471292800, 3.4712928*^9], 
      FormBox["\"2010\"", TraditionalForm], {0.020601132958329826`, 0}}, {
      NCache[3415996800, 3.4159968*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3423859200, 3.4238592*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3431808000, 3.431808*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3447532800, 3.4475328*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3455395200, 3.4553952*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3463344000, 3.463344*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
      NCache[3479068800, 3.4790688*^9], 
      FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.4795496192348824`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1306, 945},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (September 30, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 80, 1, 99, "Title"],
Cell[650, 25, 94, 1, 39, "Text"],
Cell[747, 28, 215, 4, 39, "Text"],
Cell[965, 34, 585, 9, 84, "Text"],
Cell[1553, 45, 224, 4, 39, "Text"],
Cell[1780, 51, 233, 5, 62, "Text"],
Cell[CellGroupData[{
Cell[2038, 60, 125, 2, 108, "Section"],
Cell[2166, 64, 791, 18, 372, "InputOnly",
 InitializationCell->True],
Cell[2960, 84, 358, 11, 199, "InputOnly",
 InitializationCell->True],
Cell[3321, 97, 1318, 36, 373, "InputOnly",
 InitializationCell->True],
Cell[4642, 135, 2731, 75, 304, "InputOnly",
 InitializationCell->True],
Cell[7376, 212, 13110, 304, 2590, "InputOnly",
 InitializationCell->True],
Cell[20489, 518, 267, 9, 234, "InputOnly",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[20793, 532, 119, 2, 61, "Section"],
Cell[CellGroupData[{
Cell[20937, 538, 93, 1, 51, "Subsection"],
Cell[21033, 541, 260, 5, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21330, 551, 36, 0, 51, "Subsection"],
Cell[21369, 553, 3713, 120, 248, "InputOnly",
 InitializationCell->True],
Cell[25085, 675, 545, 15, 87, "InputOnly",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[25667, 695, 37, 0, 76, "Subsection"],
Cell[25707, 697, 29, 0, 58, "Text"],
Cell[CellGroupData[{
Cell[25761, 701, 101, 2, 82, "Input"],
Cell[25865, 705, 19825, 386, 543, "Output"]
}, Open  ]],
Cell[45705, 1094, 121, 3, 58, "Text"],
Cell[CellGroupData[{
Cell[45851, 1101, 364, 7, 153, "Input"],
Cell[46218, 1110, 19945, 389, 529, "Output"]
}, Open  ]],
Cell[66178, 1502, 69, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[66272, 1508, 1268, 33, 291, "Input"],
Cell[67543, 1543, 19971, 392, 543, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87551, 1940, 1285, 34, 291, "Input"],
Cell[88839, 1976, 19975, 392, 543, "Output"]
}, Open  ]],
Cell[108829, 2371, 73, 0, 58, "Text"],
Cell[CellGroupData[{
Cell[108927, 2375, 592, 13, 222, "Input"],
Cell[109522, 2390, 19956, 392, 529, "Output"]
}, Open  ]],
Cell[129493, 2785, 263, 5, 93, "Text"],
Cell[CellGroupData[{
Cell[129781, 2794, 432, 9, 187, "Input"],
Cell[130216, 2805, 19882, 387, 529, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[150147, 3198, 32, 0, 76, "Subsection"],
Cell[CellGroupData[{
Cell[150204, 3202, 221, 4, 82, "Input"],
Cell[150428, 3208, 18696, 403, 525, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169161, 3616, 966, 23, 256, "Input"],
Cell[170130, 3641, 18839, 407, 508, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189006, 4053, 1155, 29, 291, "Input"],
Cell[190164, 4084, 18545, 407, 508, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
